# unitorch.cli.models.peft

## BloomLoraForClassification

!!! tip
    **`classification/peft/lora/bloom`** is the section for configuration of BloomLoraForClassification.

::: unitorch.cli.models.peft.BloomLoraForClassification
    
## BloomLoraForGeneration

!!! tip
    **`core/model/generation/peft/lora/bloom`** is the section for configuration of BloomLoraForGeneration.

::: unitorch.cli.models.peft.BloomLoraForGeneration

## LlamaLoraForClassification

!!! tip
    **`core/model/classification/peft/lora/llama`** is the section for configuration of LlamaLoraForClassification.

::: unitorch.cli.models.peft.LlamaLoraForClassification
    
## LlamaLoraForGeneration

!!! tip
    **`core/model/generation/peft/lora/llama`** is the section for configuration of LlamaLoraForGeneration.

::: unitorch.cli.models.peft.LlamaLoraForGeneration
